@@ -2,9 +2,9 @@ from .textbtn import TextButton  # noqa
 from .login import CookiesLoginDialog  # noqa
 from .selfpaint_btn import (  # noqa
     SelfPaintAbstractSquareButton, RecentlyPlayedButton,
-    HomeButton, LeftArrowButton, RightArrowButton, SearchButton, SettingsButton,
+    HomeButton, LeftArrowButton, RightArrowButton, SearchSwitchButton, SettingsButton,
     PlusButton, TriagleButton, DiscoveryButton,
     SelfPaintAbstractIconTextButton, CalendarButton, RankButton,
     StarButton, PlayPauseButton, PlayNextButton, PlayPreviousButton,
-    MVButton, VolumeButton,
+    MVButton, VolumeButton, HotButton, EmojiButton
 )
